@@ -20,6 +20,7 @@ from optparse import OptionParser  # pylint: disable=deprecated-module
 import os
 import re
 import socket
+from string import Template
 import sys
 
 from netaddr import (
@@ -34,19 +35,29 @@ from netaddr import (
 
 
 # Globals
-EVERYTHING = [
-    "internet at large",
+
+# Patterns for matching v4 wildcards
+EVERYTHING_V4 = [
     "*",
-    "all",
-    "any",
-    "internet",
     "0.0.0.0",
     "0.0.0.0/0",
     "0.0.0.0-255.255.255.255",
+    "all",
+    "any",
+    "internet",
+    "internet at large",
 ]
+EVERYTHING = EVERYTHING_V4  # Backwards compatibility (just in case)
+
+# Patterns for matching v6 wildcards
+EVERYTHING_V6 = [
+    "::",
+    "[::]",
+]
+
 # IPRange objects larger than MAX_RANGE_LEN will always be strict.
-# This is an IPv4 /18
-MAX_RANGE_LEN = 16384
+# This is an IPv4 /16
+MAX_RANGE_LEN = 65535
 
 # Setup logging
 DEBUG = os.getenv("DEBUG")
@@ -156,7 +167,7 @@ def parse_brackets(text):
         network = prefix + "."
 
     else:
-        raise NotBracketStyle("Bracketed style not parseable: '%s'" % text)
+        raise NotBracketStyle(f"Bracketed style not parseable: {next}")
 
     # Split hyphenated [x-y]
     if "-" in enders:
@@ -253,7 +264,9 @@ def is_ipv6(ipstr):
         return False
 
 
-def cidrize(ipstr, strict=False, raise_errors=True):
+def cidrize(
+    ipstr, strict=False, raise_errors=True
+):  # pylint: disable=too-many-return-statements, too-many-branches
     """
     This function tries to determine the best way to parse IP addresses correctly & has
     all the logic for trying to do the right thing!
@@ -334,11 +347,16 @@ def cidrize(ipstr, strict=False, raise_errors=True):
     # Otherwise try everything else
     result = None
     try:
-        # Parse "everything" & immediately return; strict/loose doesn't apply
-        if ipstr in EVERYTHING:
+        # Parse "everything" v4 & immediately return; strict/loose doesn't apply
+        if ipstr in EVERYTHING_V4:  # pylint: disable = no-else-return
             log.debug("Trying everything style...")
             return [IPNetwork("0.0.0.0/0")]
 
+        # Parse "everything" v6 & immediately return; strict/loose doesn't apply
+        elif ipstr in EVERYTHING_V6:
+            log.debug("Trying everything style...")
+            return [IPNetwork("::/0")]
+
         # Parse old-fashioned CIDR notation & immediately return; strict/loose doesn't apply
         # Now with IPv6!
         elif RE_CIDR.match(ipstr) or is_ipv6(ipstr):
@@ -379,9 +397,7 @@ def cidrize(ipstr, strict=False, raise_errors=True):
 
         # This will probably fail 100% of the time. By design.
         else:
-            raise CidrizeError(
-                "Could not determine parse style for '%s'" % ipstr
-            )
+            raise CidrizeError(f"Could not determine parse style for {ipstr!r}")
 
         # If it's a single host, just return it wrapped in a list
         if result.size == 1:
@@ -394,17 +410,17 @@ def cidrize(ipstr, strict=False, raise_errors=True):
         if not strict:
             if isinstance(result, IPRange) and result.size >= MAX_RANGE_LEN:
                 log.debug(
-                    "IPRange objects larger than /18 will always be strict."
+                    "IPRange objects larger than /16 will always be strict."
                 )
                 return result.cidrs()
             if isinstance(result, IPNetwork):
                 return [result.cidr]
             return [spanning_cidr(result)]
-        else:
-            try:
-                return result.cidrs()  # IPGlob and IPRange have .cidrs()
-            except AttributeError as err:
-                return [result.cidr]  # IPNetwork has .cidr
+
+        try:
+            return result.cidrs()  # IPGlob and IPRange have .cidrs()
+        except AttributeError:
+            return [result.cidr]  # IPNetwork has .cidr
 
     except (AddrFormatError, TypeError, ValueError) as err:
         if raise_errors:
@@ -453,7 +469,7 @@ def optimize_network_range(ipstr, threshold=0.9, verbose=DEBUG):
     ratio = float(len(strict)) / float(len(loose))
 
     if verbose:
-        print("Subnet usage ratio: %s; Threshold: %s" % (ratio, threshold))
+        print(f"Subnet usage ratio: {ratio}; Threshold: {threshold}")
 
     if ratio >= threshold:
         if verbose:
@@ -501,7 +517,8 @@ def normalize_address(ipstr):
 
     octets = (int(i) for i in myip.split("."))
     ipobj = ".".join([str(o) for o in octets])
-    return "{0}/{1}".format(ipobj, cidr)
+
+    return f"{ipobj}/{cidr}"
 
 
 def netaddr_to_ipy(iplist):
@@ -524,6 +541,22 @@ def netaddr_to_ipy(iplist):
     return [IPy.IP(str(x)) for x in iplist]
 
 
+DUMP_TEMPLATE = """
+Information for $cidr
+
+IP Version:\t\t$cidr_version
+Spanning CIDR:\t\t$cidr
+Block Start/Network:\t$ip_first
+1st host:\t\t$ip_firsthost
+Gateway:\t\t$ip_gateway
+Block End/Broadcast:\t$ip_bcast
+DQ Mask:\t\t$ip_netmask
+Cisco ACL Mask:\t\t$ip_hostmask
+# of hosts:\t\t$num_hosts
+Explicit CIDR blocks:\t$orig_cidr_str
+"""
+
+
 def dump(cidr):
     """
     Dumps a lot of info about a CIDR.
@@ -543,28 +576,20 @@ def dump(cidr):
     log.debug("dump(): Single? %r", single)
     log.debug("dump(): Got? %r", cidr)
 
-    ip_first = IPAddress(cidr.first)
-    ip_firsthost = ip_first if single else next(cidr.iter_hosts())
-    ip_gateway = IPAddress(cidr.last - 1)
-    ip_bcast = cidr.broadcast
-    ip_netmask = cidr.netmask
-    ip_hostmask = cidr.hostmask
-    num_hosts = 1 if single else (cidr.last - 1) - cidr.first
-
-    out = ""
-    out += "Information for %s\n\n" % cidr
-    out += "IP Version:\t\t%s\n" % cidr.version
-    out += "Spanning CIDR:\t\t%s\n" % cidr
-    out += "Block Start/Network:\t%s\n" % ip_first
-    out += "1st host:\t\t%s\n" % ip_firsthost
-    out += "Gateway:\t\t%s\n" % ip_gateway
-    out += "Block End/Broadcast:\t%s\n" % ip_bcast
-    out += "DQ Mask:\t\t%s\n" % ip_netmask
-    out += "Cisco ACL Mask:\t\t%s\n" % ip_hostmask
-    out += "# of hosts:\t\t%s\n" % num_hosts
-    out += "Explicit CIDR blocks:\t%s\n" % output_str(orig_cidr)
-
-    return out
+    return Template(DUMP_TEMPLATE).substitute(
+        cidr=cidr,
+        cidr_version=cidr.version,
+        ip_first=IPAddress(cidr.first),
+        ip_firsthost=IPAddress(cidr.first)
+        if single
+        else next(cidr.iter_hosts()),
+        ip_gateway=IPAddress(cidr.last - 1),
+        ip_bcast=cidr.broadcast,
+        ip_netmask=cidr.netmask,
+        ip_hostmask=cidr.hostmask,
+        num_hosts=1 if single else (cidr.last - 1) - cidr.first,
+        orig_cidr_str=output_str(orig_cidr),
+    )
 
 
 def parse_args(argv):
@@ -579,6 +604,12 @@ debug output set the DEBUG environment variable.""",
     )
 
     parser.add_option("-h", "--help", action="store_false")
+    parser.add_option(
+        "-s",
+        "--strict",
+        action="store_true",
+        help="Enable strict parsing. (Default: loose)",
+    )
     parser.add_option(
         "-v",
         "--verbose",
@@ -647,7 +678,7 @@ def main():
     ipstr = opts.ip
 
     try:
-        cidr = cidrize(ipstr, raise_errors=False)
+        cidr = cidrize(ipstr, raise_errors=False, strict=opts.strict)
         if cidr:
             if opts.verbose:
                 print(dump(cidr))
@@ -656,6 +687,8 @@ def main():
     except IndexError:
         return -1
 
+    return 0
+
 
 if __name__ == "__main__":
     sys.exit(main())
